package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````'!H!`#0```"@P0````0`!30`(``)
M`"@`'0`<``$``'"LMP``K+<!`*RW`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0"XMP``N+<```4```````$`
M`0```)2]``"4O0(`E+T"`'P"``"H$@``!@```````0`"````N+T``+B]`@"X
MO0(`*`$``"@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DE+T`
M`)2]`@"4O0(`;`(``&P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50!@3`:N'@Y\5Q.2Y+<W_"\JOZ:KM6$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@:0"$"3Y"/)<``0`()%B`!(E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`D`D``D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#0````\`
M```0````$0```!,````6`````````````````````````!@````;````'```
M```````@````(0```"(`````````(P```"0````H`````````"H`````````
M`````"L````L````+0```"X`````````,@```#,````W````.```````````
M````.0```#P````]`````````#X````_````00```$,```!&`````````$@`
M``!)````2@```$L`````````3```````````````````````````````````
M`$T```!.`````````%``````````4@```%0```!6````````````````````
M`````%<```!;`````````%P`````````7@````````!@````80``````````
M````8P```&0```!F````9P```&H```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#C^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'?JF<FV+0^H+L
M+/:+:W^:?(?PEGSN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7
MQ!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````%```````````````"````!L`P`````````````2````-@(`````````
M````$@```,T"`````````````!(```"Q`@`````````````2````;00```#`
M`@``````(``8`*<!`````````````!(```"J`@`````````````2````EP$`
M`$P5`0``````$@```-8#```0P`(``````!``&0!D`@`````````````2````
MCP(`````````````$@```*T$```,P`(`!````!$`&``0`P`````````````2
M````^00``$AR`0!8`P``$@`-`%($``"$8P$`)`$``!(`#0!S`P``````````
M```2````=0(`````````````$@```"$#`````````````!(```#E`P``/-`"
M```````0`!D`,`0`````````````$@```%X$```,:`$`/`H``!(`#0"'!```
M8&`!`.0````2``T`100``%QC`0`H````$@`-`)P"`````````````!(```!?
M`@`````````````2````<`$`````````````$@```/T"`````````````!(`
M``"&`P``$,`"``0````A`!D`'@(`````````````$@```"4"````````````
M`!(```"_`@`````````````2````PP,``!#``@``````$``8`-H"````````
M`````!(```"'````=!<!```````2````I`(`````````````$@```#X#````
M`````````!(````8`@`````````````2````/@(`````````````$@```(<#
M```0P`(`!````"$`&0#P`P``/-`"```````0`!D`&@,``"#``@`$````$0`9
M`/T#``"@=@$`!````!(`#0![`0`````````````2````5P$`````````````
M$@```)T$``!`=@$`8````!(`#0#9!```[&8!`"`!```2``T`!P0``*1V`0``
M````$@`.`'X"`````````````!(```!Q!```'!H!```````2``T`Q@0``,`4
M`0``````$@`+`*<``````````````!(```"S```````````````2````[P(`
M````````````$@```/<````<P`(``0```!$`&0"X`@`````````````2````
M>`0``*QV`0`$````$0`/`,H#```0P`(``````!``&0!%`P`````````````2
M````70,`````````````$@```&H``````````````!(````$`0``````````
M```2````Q`0``-A?`0`T````$@`-`"`!`````````````!(```#X`P``/-`"
M```````0`!D`S`0``$AA`0`4`@``$@`-`,@``````````````!(```!-`@``
M```````````2````!`(`````````````$@```(D!`````````````!(```#6
M```````````````2````Z```````````````$@```!4!```8P`(`!````!$`
M&0"%`P``$,`"``0````1`!D`20$`````````````$@```,8"````````````
M`!(```#D`P``/-`"```````0`!D`ZP0``%AF`0!\````$@`-`)@`````````
M`````!(````(`P`````````````2````:P0```#``@``````$``8`$\#````
M`````````!(```"C`P``H+T"``0````1`!4`'@0``-1F`0`8````$@`-`,4!
M`````````````!(```"R`0`````````````2````@`,``/@7`0`D`@``$@`-
M`"4!`````````````!(````H`P`````````````2````T`$``*2]`@`3````
M$0`5`.@"`````````````!(```#4`@`````````````2````;`(`````````
M````$@```+X!`````````````!(```!E`P`````````````2````MP0``*AD
M`0"P`0``$@`-`#$#`````````````!(````J`0`````````````2````E@(`
M````````````$@```#D$``"@=0$`?````!(`#0!X```````````````2````
M9P$`````````````$@````T$``!$80$`!````!(`#0`V`0``_!8!```````2
M`````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?
M,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE
M=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F
M971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI
M8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R
M:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?<W1A8VM?8VAK
M7V=U87)D`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?
M9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?
M;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I
M;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R
M+C0````````````````"``,``@`"``$````"`````0`"``(``0`"``$``0`"
M``(``@`!``(``0`!``$``@`"`````@`"``,``P`"``$``@````(``@`#``,`
M`@`!``(``0```````0`!``$``@`!``$```````(````"``$``0`"``(`````
M``$````!``$````"``,````````````"`````@`!``$````"``$``@`$``$`
M``````$``@`"`````@`"``(``@`"``$``@````(``0```````0```````0`!
M`(\#```0````(````!1I:0T```0`#P4````````!``$`]`$``!`````@````
M%&EI#0```P`/!0````````$``0!#`@``$``````````4:6D-```"``\%````
M````]+\"`!4"``"@O0(`%%8``*2]`@`470``$,`"`!1-```8P`(`%$P``!S`
M`@`4.@``(,`"`!0M``#LO@(`%@<``/"^`@`6!0``]+X"`!88``#XO@(`%BH`
M`/R^`@`6%@```+\"`!8_```$OP(`%EL```B_`@`61@``#+\"`!9>```0OP(`
M%@P``!2_`@`67P``&+\"`!92```<OP(`%D,``""_`@`6.0``)+\"`!8T```H
MOP(`%D<``"R_`@`6#P``,+\"`!8<```TOP(`%B\``#B_`@`63@``/+\"`!9<
M``!`OP(`%F0``$2_`@`62@``2+\"`!98``!,OP(`%@8``%"_`@`660``5+\"
M`!93``!8OP(`%B$``%R_`@`680``8+\"`!84``!DOP(`%C```&B_`@`6`@``
M;+\"`!8(``!POP(`%AT``'2_`@`6(P``>+\"`!9H``!\OP(`%B@``("_`@`6
M-P``A+\"`!8B``"(OP(`%E4``(R_`@`6.```D+\"`!9@``"4OP(`%AX``)B_
M`@`69@``G+\"`!9/``"@OP(`%FL``*2_`@`60```J+\"`!9E``"LOP(`%@H`
M`+"_`@`6)0``M+\"`!9!``"XOP(`%@L``+R_`@`68@``P+\"`!8[``#$OP(`
M%DD``,B_`@`6)@``S+\"`!8^``#0OP(`%DL``-2_`@`6:0``V+\"`!81``#<
MOP(`%@X``."_`@`6)P``Y+\"`!8I``#HOP(`%A\``.R_`@`6%0``\+\"`!9(
M```(0"WI8P$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E!*H!``#&C^(:RHSB!/J\
MY0#&C^(:RHSB_/F\Y0#&C^(:RHSB]/F\Y0#&C^(:RHSB[/F\Y0#&C^(:RHSB
MY/F\Y0#&C^(:RHSBW/F\Y0#&C^(:RHSBU/F\Y0#&C^(:RHSBS/F\Y0#&C^(:
MRHSBQ/F\Y0#&C^(:RHSBO/F\Y0#&C^(:RHSBM/F\Y0#&C^(:RHSBK/F\Y0#&
MC^(:RHSBI/F\Y0#&C^(:RHSBG/F\Y0#&C^(:RHSBE/F\Y0#&C^(:RHSBC/F\
MY0#&C^(:RHSBA/F\Y0#&C^(:RHSB?/F\Y0#&C^(:RHSB=/F\Y0#&C^(:RHSB
M;/F\Y0#&C^(:RHSB9/F\Y0#&C^(:RHSB7/F\Y0#&C^(:RHSB5/F\Y0#&C^(:
MRHSB3/F\Y0#&C^(:RHSB1/F\Y0#&C^(:RHSB//F\Y0#&C^(:RHSB-/F\Y0#&
MC^(:RHSB+/F\Y0#&C^(:RHSB)/F\Y0#&C^(:RHSB'/F\Y0#&C^(:RHSB%/F\
MY0#&C^(:RHSB#/F\Y0#&C^(:RHSB!/F\Y0#&C^(:RHSB_/B\Y0#&C^(:RHSB
M]/B\Y0#&C^(:RHSB[/B\Y0#&C^(:RHSBY/B\Y0#&C^(:RHSBW/B\Y0#&C^(:
MRHSBU/B\Y0#&C^(:RHSBS/B\Y0#&C^(:RHSBQ/B\Y0#&C^(:RHSBO/B\Y0#&
MC^(:RHSBM/B\Y0#&C^(:RHSBK/B\Y0#&C^(:RHSBI/B\Y0#&C^(:RHSBG/B\
MY0#&C^(:RHSBE/B\Y0#&C^(:RHSBC/B\Y0#&C^(:RHSBA/B\Y0#&C^(:RHSB
M?/B\Y0#&C^(:RHSB=/B\Y0#&C^(:RHSB;/B\Y0#&C^(:RHSB9/B\Y0#&C^(:
MRHSB7/B\Y0#&C^(:RHSB5/B\Y0#&C^(:RHSB3/B\Y0#&C^(:RHSB1/B\Y0#&
MC^(:RHSB//B\Y0#&C^(:RHSB-/B\Y0#&C^(:RHSB+/B\Y0#&C^(:RHSB)/B\
MY0#&C^(:RHSB'/B\Y0#&C^(:RHSB%/B\Y0#&C^(:RHSB#/B\Y0#&C^(:RHSB
M!/B\Y0#&C^(:RHSB_/>\Y7!`+>D@T$WBW%&?Y10`C>40$(WE`#"5Y0P@C>40
M$(WB#""-XA0`C>(<,(WEEO__Z[@AG^6X`9_E`A"@X7@7`.NP,9_E`&#3Y0``
M5N.H09\5"0``&FC__^N@(9_E``!0X^@/`N5>```*C$&?Y3[__^L``)3EWO__
MZX%FP.4``)3EV___ZP`@H.$``)3E#C32Y0(P@^,.-,+EU?__ZQ0PG>4%,(/B
M!P%SXPXDT.4!((+C#B3`Y3\``(H#`:#A5/__ZQ#`G>4X,9_E,$&?Y0`0G.44
M()WE`0!2XP#@H.$$`)/E(#&?Y0`0CN4<$9_E!#".Y00PH.,,$([E]#\$Y0@`
MCN4$,(S"\.\$Y0+!C,`,$(["`P``V@0`D^0#`%SA!`"AY?O__QH-P8+B`!"@
MX^@/%.4#((+B`!"-Y0XPH.$,$8[GR!"?Y7?__^L`8%#B$```"N@/%.49___K
M&!"-XK``G^49$`#K``!0XPT```KH#Q3E`/__ZV7__^L<()WE`#"5Y08`H.$#
M`%+A%```&B#0C>)P@+WHZ`\4Y8#__^L`8*#AZO__ZNP/%.4``%#C!```"OP6
M`.OL___J6!"?Y5@`G^5`___K&!"-XE``G^7^#P#K``!0X^P/!.7C__\*\___
MZNK^_^L!`*#C(?__ZZ"]`@#\%@$`=!<!`!S``@`8P`(`(.`"``C``@`X>@$`
M/'H!``Q@`0#P=P$`I+T"`!QY`0",=P$``+"@XP#@H.,$$)WD#2"@X00@+>4$
M`"WE$,"?Y03`+>4,`)_E##"?Y?S^_^M;___KH'8!`/@7`0!`=@$`%#"?Y10@
MG^4#,(_@`B"3YP``4N,>_R\!]_[_ZGBD`0`4`0``'#"?Y1P`G^4`,$/@!@!3
MXQ[_+Y$0,)_E``!3XQ[_+P$3_R_A$\`"`!#``@``````)!"?Y20`G^4`$$'@
M01&@X:$?@>#!$+#A'O\O`1`PG^4``%/C'O\O`1/_+^$0P`(`$,`"```````0
M0"WI&$"?Y0`PU.4``%/C$("]&-___^L!,*#C`##$Y1"`O>@DP`(`*`"?Y0`P
MD.4``%/C````&N+__^H8,)_E``!3X_O__PH00"WI,_\OX1!`O>C;___JG+T"
M````````````B!2?Y?!/+>F_WTWB`!"1Y3@@@.)XX(#B<#"-X@#`H.-,`(WE
M]!*-Y01`DN4,P(WE`%"@XR04H.$$I*#A`A"-Z"0<H.$($(WET`#-X=A@S>$`
M$*#C_PP`X@!@AN$!<(?A!$R@X08`H.$'$*#A!`"`X0!@DN7_2`KB!`"`X040
M@>$(((+B-F^_Y@X`4N$$P(/E^`##X0!@@^40,(/BX?__&FC`C>*:[XWB#$"@
MX=@`[.'0)\3AV&3$X=A!Q.$&H"+@!"`JX`>P(^``0"+@!3`KX`%0(^"DCZ#A
M!`"4X(6`B.$(0(#A!""@X0`PH.,.`%SA\"C,X>O__QI,8)WE`$"@XP!0H./0
M(,;AV*'&X00`H.$%$*#AHGV@X?``S>'PHLWAT`'&X0!PC>70HL;AV&#&X7C`
MC>+PI<WAV(!,X0:@H.$'L*#ASW^/XM!@Q^'P(<WA@U*@X:,]H.$$,(WE"&"6
MX*)=A>&"0J#AT"+-X0EPI^``4(WE!H"@X0>0H.$`8*#A`7"@X0)@)N`#<"?@
MT"#-X?@!S>$``*#C!"""X=!%S>$`$*#C"$"4X`E0I>`+GZ#A\$#-X0I`H.$+
M4*#A^`#-X09`!.`,D(WE!U`%X`1@H.$%<*#A"D"@X0M0H.'0@,WA##"=Y2H!
MH.'0HLWA)#&#X0*`F.`,,(WE!J`JX`0_H.$'L"O@`)"IX@@PC>4*H)C@"W"@
MX0>PJ>#8@,WA!0^`X?"CS>$`@(CA`+"@XP"0H.,)$*#A"""@X0@`H.'8@<WA
MBS*@X:H]@^$!D"G@^$7-X?@"S>'00,SA!#"-Y=`!S>$"@"C@`V"@X0D0`>`!
MD*#A(3Z/XM`@P^&*$J#A"```X``0C>4`@*#AT`+-X00@DN`%,*/@`@"0X`,0
MH>``(*#A`3"@X0``H.,`$*#CV$'-X?@`S>'0`,WA"$`DX`E0)>`&`(#A!&"2
MX`5PH^#0(<WA`X^@X0R`C>4`@);@`)"GX@P`G>4(8*#A"7"@X2(1@.'X8\WA
M(D&@X0!PH.,,$(WE`T^$X0(?H.$`,*#C`""@XP@0C>6'8J#A\"#-X01@C>78
M(,WA!#"=Y0>0H.&H/8/A!"""X00PC>4"8*#A`P"@X=`CS>$`<*#CV$#,X08@
M`N`',`/@\&/-X4I_C^+08,?A!&"6X`5PI^`&0*#AB&*@X0!@C>4'4*#AV&'-
MX01@EN`%<*?@V$+-X?A@S>'08,WA"D#$X0M0Q>$"0(3A`U"%X0`@H.,`,*#C
M`&"&X=@`S>'P(,WA"S^@X00PC>4$`)#@!$"=Y040H>`&()#@`#"AXBI!A.$$
M`*#A!$"-Y0I/H.'08<SA`J"@X0!`C>7P),WAT"#-X0`PH.,`$*#C`"""X0(`
MH.$`(*#C`+"@X_`@S>&J/:#A`#"-Y6@PC^+0(,/ABU*@X:I=A>$&()+@!S"C
MX`)@H.$#<*#AV"/-X?@#S>$`4(WE`"`"X`$P`^#8`LWA^"#-X0`@H.,&`)#@
M!Q"AX-!CS>'X`LWAV`#-X0A@QN$)<,?A!@"`X0<0@>'88LWA`3"@X0(``.J9
M>8):`````*"]`@"K':#A`&"6X`-PI^``,*#C!!"-Y?@@S>'0`,WA"3^@X0PP
MC>4,$)WEBD*@X00`@.$`();@*!&!X0P0C>4`,*?B`4"@X0@?H.$($(WE`H"@
MX?`FS>'8(,WA`#"@X]AAS.$$((+A`@"@X0`@H.,`$*#C\"#-X:@]H.$`,(WE
MRC^/XM`@P^'X`LWA`)"@XP8@DN`',*/@`F"@X0-PH.'0),WAB5*@X:A=A>$`
M(`+@`3`#X-`#S>'X(,WA`%"-Y08`D.`'$*'@V&/-X?`#S>'8`,WA"W#'X0I@
MQN$'$('A`3"@X:D=H.$$$(WE!@"`X=!CS>$`(*#CB$*@X0!@EN`#<*?@`#"@
MX]``S>'X(,WA"S^@X0PPC>4,$)WE!`"`X0`@EN`J$8'A#!"-Y0`PI^(!0*#A
M"A^@X0@0C>4"H*#A\"3-X=@@S>$`,*#CT&+,X00@@N$"`*#A`""@XP`0H./P
M(,WAJCV@X0`PC>6//X_BT"##X?`#S>$`L*#C!B"2X`<PH^`"8*#A`W"@X=`F
MS>&+4J#AJEV%X0`@`N`!,`/@V`/-X?@@S>$`(*#C!@"0X`<0H>#88LWA^`/-
MX=@`S>$(8,;A"7#'X08`@.$'$('AV&/-X0$PH.&K':#A`&"6X`-PI^``,*#C
M`%"-Y000C>7X(,WAT`#-X0D_H.$,,(WEBD*@X0P0G>4$`(#A`""6X"@1@>$`
M,*?B#!"-Y0%`H.$('Z#A"!"-Y0*`H.'P)LWAV"#-X0`PH./88LSA!"""X0(`
MH.$`(*#C`!"@X_`@S>&H/:#A`#"-Y14^C^+0(,/A^`/-X0"0H.,&()+@!S"C
MX`)@H.$#<*#AT"3-X8E2H.&H787A`"`"X`$P`^#8`LWA^"#-X0`@H.,&`)#@
M!Q"AX-!CS>'X`LWAV`#-X0I@QN$+<,?A!@"`X0<0@>'88LWA`3"@X:D=H.$`
M8);@`W"GX``PH.,`4(WE!!"-Y?@@S>'0`,WA"S^@X0PPC>4,$)WEB$*@X00`
M@.$`();@*A&!X0P0C>4`,*?B`4"@X0H?H.$($(WE`J"@X?`DS>'8(,WA`#"@
MX]!CS.$$((+A`@"@X0`@H.,`$*#C\"#-X:H]H.$`,(WE9#"/XM`@P^'X`LWA
M`+"@XP8@DN`',*/@`F"@X0-PH.'0)LWABU*@X:I=A>$`(`+@`3`#X-`#S>'X
M(,WA`""@XP8`D.`'$*'@V&/-X?`#S>'8`,WA"&#&X0EPQ^$&`(#A!Q"!X=!C
MS>$#``#JF7F"6@````"9>8):``````$PH.&K':#A`&"6X`-PI^``,*#C`%"-
MY000C>7X(,WAT`#-X0D_H.$,,(WE#!"=Y8I"H.$$`(#A`""6X"@1@>$,$(WE
M`#"GX@%`H.$('Z#A"!"-Y0*`H.'P)LWAV"#-X0`PH./88\SA!"""X0(`H.$`
M(*#C`!"@X_`@S>&H/:#A`#"-Y90P3^+0(,/A\`/-X0"0H.,&()+@!S"CX`)@
MH.$#<*#AT"3-X8E2H.&H787A`"`"X`$P`^#8`\WA^"#-X0`@H.,&`)#@!Q"A
MX-ABS>'X`\WAV`#-X0I@QN$+<,?A!@"`X0<0@>'88\WA`3"@X:D=H.$`8);@
M`W"GX``PH.,`4(WE!!"-Y?@@S>'0`,WA"S^@X0PPC>6(0J#A#!"=Y00`@.$`
M();@*A&!X0`PI^(,$(WE`4"@X0H?H.$($(WE`J"@X?`DS>'8(,WA`#"@X]!D
MS.$$((+A`@"@X0`@H.,`$*#C\"#-X:H]H.$`,(WE!CU/XM`@P^$`L*#CBD*@
MX08@DN`',*/@`F"@X0-PH.'0)LWA^`/-X8M2H.$`(`+@`3`#X-@"S>'X(,WA
MJEV%X08`D.`'$*'@T&/-X?@"S>'8`,WA"&#&X0EPQ^$&`(#A!Q"!X=ABS>$!
M,*#A`""@XP!@EN`#<*?@JQV@X0`PH.,`4(WE!!"-Y?@@S>'0`,WA"3^@X0PP
MC>4,$)WE!`"`X0`@EN`H$8'A#!"-Y0`PI^(!0*#A"!^@X0@0C>4"@*#A\";-
MX=@@S>$`,*#CV&3,X00@@N$"`*#A`""@XP`0H./P(,WAJ#V@X0`PC>6;/T_B
MT"##X?@"S>$`D*#C!B"2X`<PH^`"8*#A`W"@X=`DS>&)4J#AJ%V%X0`@`N`!
M,`/@T`/-X?@@S>$`(*#C!@"0X`<0H>#88\WA\`/-X=@`S>$*8,;A"W#'X08`
M@.$'$('AT&/-X0$PH.&I':#A`&"6X`-PI^``,*#C`%"-Y000C>7X(,WAT`#-
MX0L_H.$,,(WE#!"=Y8A"H.$$`(#A`""6X"H1@>$,$(WE`#"GX@%`H.$*'Z#A
M"!"-Y0*@H.'P),WAV"#-X0`PH./09<SA!"""X0(`H.$`(*#C`!"@X_`@S>&J
M/:#A`#"-Y<H_C^+0(,/A\`/-X0"PH.,&()+@!S"CX`)@H.$#<*#AT";-X8M2
MH.&J787A`"`"X`$P`^#8`\WA^"#-X0`@H.,&`)#@!Q"AX-ABS>'X`\WAV`#-
MX0A@QN$)<,?A!@"`X0<0@>'88\WA`3"@X:L=H.$`8);@`W"GX``PH.,`4(WE
M!!"-Y?@@S>'0`,WA"3^@X0PPC>4,$)WEBD*@X00`@.$`();@*!&!X0`PI^(,
M$(WE`4"@X0@?H.$($(WE`H"@X?`FS>'8(,WA`#"@X]AES.$$((+A`@"@X0`@
MH.,`D*#C\"#-X:@]H.$`,(WECS^/XM`@P^$`$*#CB5*@X08@DN`',*/@`F"@
MX0-PH.'0),WAJ%V%X?@#S>$`(`+@`3`#X(A"H.'X(,WA`%"-Y=@"S>$`(*#C
M!@"0X`<0H>#08\WA^`+-X=@`S>$*8,;A"W#'X08`@.$'$('AV&+-X0$PH.&I
M':#A`&"6X`-PI^``,*#C!!"-Y?@@S>'0`,WA"S^@X0PPC>4,$)WE!`"`X0`@
MEN`J$8'A#!"-Y0`PI^(!0*#A"A^@X0@0C>4"H*#A\"3-X=@@S>$`,*#CT&;,
MX00@@N$"`*#A`""@XP`0H./P(,WAJCV@X0`PC>45/H_BT"##X?@"S>$`L*#C
M!B"2X`<PH^`"8*#A`W"@X=`FS>&+4J#AJEV%X0`@`N`!,`/@T`/-X?@@S>$`
M(*#C!@"0X`<0H>#88\WA\`/-X=@`S>$(8,;A"7#'X08`@.$'$('AT&/-X0$P
MH.&K':#A`&"6X`-PI^``,*#C`%"-Y000C>7X(,WAT`#-X0D_H.$,,(WEBD*@
MX0P0G>4$`(#A`""6X"@1@>$`,*?B`4"@X0P0C>4('Z#AV&;,X0@0C>4"@*#A
M\";-X=@@S>$`,*#C`!"@XP0@@N$"`*#A`""@X_`#S>'P(,WAJ#V@X0`PC>5@
M,(_BT"##X0"0H..(0J#A!B"2X`<PH^`"8*#A`W"@X=`DS>&)4J#AJ%V%X0`@
M`N`!,`/@V`/-X?@@S>$`(*#C!@"0X`<0H>#88LWA^`/-X=@`S>$*8,;A"W#'
MX08`@.$'$('A`P``ZIEY@EH`````F7F"6@````#88\WA`3"@X:D=H.$`8);@
M`W"GX``PH.,`4(WE!!"-Y?@@S>'0`,WA"S^@X0PPC>4,$)WE!`"`X0`@EN`J
M$8'A`#"GX@P0C>4!0*#A"A^@X0@0C>4"H*#A\"3-X=@@S>$`,*#CT&?,X00@
M@N$"`*#A`""@XP`0H./P(,WAJCV@X0`PC>64,$_BT"##X?@#S>$`L*#C!B"2
MX`<PH^`"8*#A`W"@X=`FS>&+4J#AJEV%X0`@`N`!,`/@V`+-X?@@S>$`4(WE
M!@"0X`<0H>``(*#C^`+-X=!CS>'8`,WABD*@X0A@QN$)<,?A!@"`X0<0@>'8
M8LWA`3"@X:L=H.$`8);@`W"GX``PH.,$$(WE^"#-X=``S>$)/Z#A##"-Y0P0
MG>4$`(#A`""6X"@1@>$,$(WE`#"GX@%`H.$('Z#A"!"-Y0*`H.'P)LWAV"#-
MX0`PH./89\SA!"""X0(`H.$`(*#C`!"@X_`@S>&H/:#A`#"-Y08]3^+0(,/A
M^`+-X0"0H.,&()+@!S"CX`)@H.$#<*#AT"3-X8E2H.&H787A`"`"X`$P`^#0
M`\WA^"#-X0!0C>4&`)#@!Q"AX-ACS>'P`\WAV`#-X0I@QN$+<,?A!@"`X0<0
M@>'08\WA`3"@X:D=H.$`8);@`W"GX`00C>4`(*#C`#"@X]``S>'X(,WA"S^@
MX0PPC>6(0J#A!`"`X0P0G>4`();@`#"GXBH1@>$!0*#A#!"-Y0H?H.'0:,SA
M`J"@X0@0C>7P),WAV"#-X0`PH.,`$*#C!"""X0(`H.$`(*#C\`/-X?`@S>&J
M/:#A`#"-Y2<^3^+0(,/A`+"@XXI"H.$&()+@!S"CX`)@H.$#<*#AT";-X8M2
MH.&J787A`"`"X`$P`^#8`\WA^"#-X0`@H.,&`)#@!Q"AX-ABS>'X`\WAV`#-
MX0A@QN$)<,?A!@"`X0<0@>'88\WA`3"@X:L=H.$`8);@`W"GX``PH.,$$(WE
M`%"-Y?@@S>'0`,WA"3^@X0PPC>4,$)WE!`"`X0`@EN`H$8'A`#"GX@P0C>4!
M0*#A"!^@X0@0C>4"@*#A\";-X=@@S>'8:,SA`!"@XP0@@N$-78_BT$#%X0&0
MH.$``*#C!D"4X``0H.,'4*7@\`#-X01@H.$%<*#A`!"@X]!$S>$!,*#AB1*@
MX000C>7X(\WA`D`$X`0@G>4#4`7@J#V"X00PC>78(LWAJ`V@X8D"@.$&()+@
M!S"CX"L1H.'X(LWAT"/-X0H@PN$$((+AB$*@X0!`C>7X@,WAT(#-X=ABS>$+
M,,/A!3"#X0)@EN``@(CA`W"GX`@@EN``,*?B`H"@X0.0H.$+7Z#A^(+-X0"0
MH.,),*#A*E&%X0I/H.$!L(7A!:"$X0J`H.$+D*#AF5^/XM!`Q>'0J<SA@Q*@
MX:(=@>$$$(WE`6"@X=`#S>$$H)K@!;"KX-!&S>'PA,WA"@"0X`"0H.,+$*'@
M"$`$X`E0!>``H*#A`;"@X?"&S>'8`,WAV(/-X0``R.$!$,GA!9"!X02`@.&"
M$J#A`!"-Y0H`F.`+$*G@T(#-X0!`H.,&@(CA"*"0X`"PH>+8`,WA\*/-X=B)
MS.$!?Z#A('&'X0!OH.$A4:#A"@"@X06PA^$'H(;AT&3-X0`0H./XH,WA"F`F
MX`!0H./8HLWA\$#-X?B&S>&!0J#A!$"-Y=B&S>%C7X_BT$#%X0:@*N`*8*#A
MV*/-X02`F.`$0)WE!9"IX`B@FN"@383A"H"@X8"BH.$$0(WE`*"-Y0FPJ^`&
MH)C@T(#-X:!-H.&!0H3A!("(X0"PJ^((H)K@`+"KX@-_H.$B<8?A`F^@X2-1
MH.'XH\WA`+"@XPH@H.$+,*#A!Z"&X06PA^$*0*#A"U"@X="*S.'X0LWA^%"/
MXM!`Q>'88,WA@[*@X0A`E.`)4*7@!("@X060H.'00\WA"F`FX**]B^$&0"3@
MT&;-X0"PC>6"HJ#A"&"6X`:`H.&C;:#A!&"-Y0EPI^`$8)C@`'"GXM"`S>'P
M8\WA`7^@X0J`B.'0H\WA('&'X0!OH.$(H)K@`+"KX@J`H.$+D*#A(5&@X?"$
MS>$'@(;A!9"'X0A@H.$)<*#AV(+-X0`0H.,*`*#A\&/-X4RPC^+0H,OA!H`H
MX(%"H.'8:LSAH$V$X01`C>780\WA"F"6X`MPI^`(L)WE@**@X0A`).``H(WE
M"V"6X`2`H.$`<*?B"*"6X`,``.J9>8):`````*'KV6X`````T(#-X:!-H.&!
M0H3A`+"GX@-_H.$B<8?A!("(X0)OH.$C4:#A"*":X`60A^$'@(;A"&"@X0EP
MH.'0@\WA^&#-X5!03^+00,7A!H`HX-!KS.$`L*OB"B"@X01@EN`%<*?@T$3-
MX?BCS>$`L*#C"S"@X2A0G>4(0"3@B[*@X05@EN"JO8OA!("@X:--H.$$0(WE
M`+"-Y0!PI^((0);@`%"GXM"`S>'X0LWABJ*@X0J`B.'8HLWA`7^@X2!QA^$(
MH)K@`+"KX@J`H.$+D*#A`&^@X2%1H.'PA,WA!9"'X0>`AN$*`*#A";"@X0B@
MH.'8@,WA`!"@X]AKS.$*@"C@@4*@X?BBS>%%OT_BT*#+X:!-A.$$0(WEV$/-
MX0I@EN`+<*?@,+"=Y8"BH.$(0"3@`*"-Y0M@EN`$@*#A`'"GX@B@EN#0@,WA
MH$V@X8%"A.$`L*?B`W^@X2)QA^$$@(CA`F^@X2-1H.$(H)K@!9"'X0>`AN$(
M8*#A"7"@X=B"S>'P8\WA&5Y/XM!`Q>$&@"C@T&S,X0"PJ^(*(*#A!&"6X`5P
MI^#01,WA^*/-X0"PH.,+,*#A"%"=Y0A`)."+LJ#A!6"6X*J]B^$$@*#AHTV@
MX0"PC>4$0(WE`'"GX@A`EN``4*?BT(#-X?A`S>&*HJ#A"H"(X=B@S>$!?Z#A
M('&'X0B@FN``L*OB"H"@X0N0H.$`;Z#A(5&@X?"$S>$'@(;A!9"'X0A@H.$)
M<*#AT(/-X0`0H.,*`*#A^&#-X9*_3^+0H,OA!H`HX(%"H.'8;,SAH$V$X01`
MC>780\WA"F"6X`MPI^`HL)WE@**@X0A`).`+8);@`*"-Y02`H.$`<*?B"*"6
MX-"`S>&@3:#A@4*$X0"PI^(#?Z#A(G&'X02`B.$";Z#A(U&@X0B@FN`%D(?A
M!X"&X0A@H.$)<*#AV(#-X;-?3^+00,7A^&+-X0:`*.#0;<SA`+"KX@H@H.$$
M8);@!7"GX-!$S>'XH\WA`+"@XPLPH.$P4)WE"$`DX`5@EN`$@*#AHTV@X0!P
MI^($0(WE"$"6X`!0I^*+LJ#AJKV+X0"PC>7P0\WAT(#-X8JBH.$!?Z#A"H"(
MX="CS>$@<8?A`&^@X0B@FN``L*OB"H"@X0N0H.$A4:#A\(3-X060A^$'@(;A
M"@"@X0FPH.$(H*#AV(+-X0`0H./PH\WAV&W,X0J`*."!0J#AU[^/XM"@R^&@
M383A!$"-Y=A#S>$*8);@"W"GX`BPG>6`HJ#A"$`DX`"@C>4+8);@!("@X0!P
MI^((H);@T(#-X:!-H.&!0H3A`+"GX@-_H.$B<8?A!("(X0)OH.$C4:#A"*":
MX`60A^$'@(;A"&"@X0EPH.'0@\WA^&#-X2Y>C^+00,7A!H`HX-!NS.$`L*OB
M"B"@X01@EN`%<*?@T$3-X?BCS>$`L*#C"S"@X2A0G>4(0"3@B[*@X05@EN"J
MO8OA!("@X:--H.$`L(WE!$"-Y0!PI^((0);@`%"GXM"`S>'X0LWABJ*@X0J`
MB.'8HLWA`7^@X2!QA^$(H)K@`+"KX@J`H.$+D*#A`&^@X2%1H.'PA,WA!X"&
MX060A^$(8*#A"7"@X=B`S>$`$*#C"@"@X0:`*."*OX_BT*#+X8%"H.'X8LWA
MV&[,X:!-A.$$0(WEV$/-X0I@EN`+<*?@,+"=Y8"BH.$(0"3@"V"6X`2`H.$`
MH(WE`'"GX@B@EN#0@,WAH$V@X8%"A.$$@(CA`+"GX@B@FN`#?Z#A(G&'X0"P
MJ^(";Z#A(U&@X0>`AN$%D(?A"&"@X?BCS>$)<*#AV(+-X6=?C^+00,7A\&/-
MX0:`*.#0;\SA`+"@XPLPH.$$8);@!7"GX-!$S>$(4)WEB[*@X0A`).`%8);@
MJKV+X02`H.&C3:#A`+"-Y01`C>4`<*?B"$"6X`!0I^+0@,WA^$#-X0H@H.&*
MHJ#A"H"(X=B@S>$!?Z#A('&'X0B@FN``L*OB"H"@X0N0H.$`;Z#A(5&@X?"$
MS>$%D(?A!X"&X0H`H.$)L*#A"*"@X="#S>$`$*#CV&_,X?B@S>$*@"C@@4*@
MX=RPC^+0H,OAH$V$X01`C>780\WA"F"6X`MPI^`HL)WE"$`DX`M@EN`$@*#A
M@**@X0"@C>4`<*?B"*"6X`"PI^+08,WAH$V@X8%"A.&A7:#A!&"&X05PA^%>
MGXWB\&#-X0"`G>4#?Z#A"*":X-"`R>$B<8?A`F^@X2-1H.'P@,WA!X"&X060
MA^$(8*#A"7"@X=B`S>'00,WA^&+-X0:`*.`\<(_BT&#'X0"PJ^(*(*#A!&"6
MX`5PI^#01,WA^*/-X0"PH.,+,*#A,%"=Y0A`).`%8);@!("@X:--H.$$``#J
M``"@X:'KV6X`````H>O9;@``````<*?B!$"-Y8NRH.$(0);@`%"GXJJ]B^$`
ML(WE\$/-X=!`S>&*HJ#A`9^@X0I`A.'0H\WA()&)X2%QH.$$H)K@`+"KX@<0
MB>$+4*#AV&+-X0:]C>(`CZ#A"D"@X0D`B.'0H,OA`("@X0&0H.$`8";@`7`G
MX-@#S>'P1,WA`%"@X_"@S>$$H*#A!;"@X09`H.$'4*#A\(/-X=!@S>$$`"#@
M!1`AX+203^+0@,GA^`/-X0@0G>4&@)C@!Y"IX`%`F."+<J#AJQV@X000C>6J
M?8?A.!"=Y0!PC>4`4*GB`8"4X-``S>&*8J#A`)"EX@8`@.$`8)C@`Q^@X0:`
MH.$B$8'A`F^@X000C>4`8(WE(U&@X=`@S>$!0*#A8A^-X@0@@N$%,(/A`D"@
MX0-0H.'0(\WAT`#!X?A`S>$$("+@`D"@X14^3^+0(,/A`'"IX@>0H.$`()+@
M`3"CX-`$S>'P)LWA*#"=Y00`(.``0*#AT`;-X?B#S>$`D*#C`P"0X``0H>*I
M/:#A!""0X(ERH.&H?8?A!#"-Y0`PH>(`<(WE^"+-X=`@S>&(8J#A"U^@X08@
M@N'88LWA&3Z-XBI1A>$"8);@`'"GXBL1H.$*3Z#A`+"@X]`@P^$%H(3A\&#-
MX0MPH.$!L(7A?5]/XM!`Q>'8`,WA^*+-X0)`E.`*`"#@`U"EX-BCS>$%,*#A
M,%"=Y0"@*N`%()3@`#"CX@I`DN``4*/B9C^-XH<2H.'0(,/AIAV!X88"H.'P
M),WA`""!X1T^C.()'Z#A`J"4X"@1@>%H,(WE"`^@X2DQH.$`D*#C`+"EX@&`
M@.$)4*#A`Y"!X=@"S>'P@\WAH3]/XM`@P^$(`"#@T(3-X?BCS>&%LJ#A"""2
MX`DPH^#0@,WA")"=Y:J]B^$)()+@`(`HX``PH^((@)+@`)"CXJ7-H.$`L(WE
M!,"-Y?B`S>'0@,WA"D"@X8JBH.$*@(CAV*#-X0<?H.$F$8'A"*":X`"PJ^(*
M@*#A"Y"@X08/H.$G,:#A"&"@X?"$S>$!@(#A`Y"!X=`#S>%JSXWB"""@X0@`
M(.`)$"'@V*!,X0DPH.$`@*#A`9"@X<\?3^+0`,'A^"#-X=@CS>$*`)#@"Q"A
MX`&PH.$(("+@"3`CX"@0G>4`<*#C\"#-X0&`D."',J#A"*"@X0"`G>6F/8/A
MAB*@X0"0J^((H)K@`X""X0"PJ>((`)K@`!"KX@&PH.$%'Z#A)!&!X000C>4!
M(*#A!!^@X0`0C>4`H*#A`$"@X=``S>$E,:#AT(#,X0(`@.$#$('AV"#-X?BC
MS>'X`LWA`"`BX-$?C^+0`,'A,,"=Y0"PH.,(`)#@"1"AX-"$S>$+4*#A)S&@
MX0*`*.`((*#A#("0X`"0H>*E':#A!!"-Y0<?H.$"@)C@)A&!X8NRH.&JO8OA
M`)"IX@-P@>'8(LWA`+"-Y08/H.'P@\WA`6"`X="`S>$&`*#A!Q"@X08@@N'8
M8\WABJ*@X0J`B.'0H\WA`F`&X`8@H.'88LWA"*":X&[/C>(`L*OB"H"@X0N0
MH.'P`\WAV*!,X0!@!N"E'X_BT`#!X0APG>7PA,WA`)"@XPH`D.`+$*'@!B""
MX0<`D."I;:#A!&"-Y0`0H>*)LJ#A`F"0X`!PH>*HO8OA`+"-Y?A@S>'08,WA
MB**@X04?H.$*8(;AV*#-X201@>$$#Z#A!J":X-!@S.$`L*OB)3&@X?A@S>'P
MILWA"F"@X0.P@>$!H(#AT`/-X0H@H.$+,*#A`J"`X0I`H.'0I,WA`@``X/@C
MS>$$H`K@"D"@X0`@H.$>OH_BT*#+X=@`S>$`4*#CICV@X05PH.$`H)K@A<*@
MX84R@^$H4)WE`;"KX*8=C.&&PJ#A!`""X0#`C>4%()K@I\V@X0@PC>4,P(WE
M`#"KX@00C>4`H)+@`+"CXMA`S>'0(,WA"1^@X2@1@>$"0(3A!*":X`"PJ^(*
M0*#A"U"@X0@/H.$I,:#A!("@X?!$S>$!0(#A`U"!X=@#S>$$(*#A!3"@X0)`
M@.$#4('A^"#-X00@H.$%,*#AT$;-X7+/C>(`D*#C`D`$X`-0!>#8(,WA\$#-
MX=B@3.$`0*#A01^/XM``P>$"0`3@T"#-X3!0G>4*`)#@"Q"AX`0@@N$%`)#@
MJ4V@X01`C>4`$*'BB;*@X0)`D.``4*'BJ+V+X0"PC>7X0LWAT$#-X8BBH.$'
M'Z#A"D"$X=BBS>$F$8'A!@^@X02@FN`G,:#AT&#,X0"PJ^(X4)WE\&/-X?"F
MS>$*8*#A`["!X0&@@.'8(,WA"@"@X0L0H.$`H(+A^`+-X=`$S>$#$*#A`'"@
MXPH``.``0*#A`@"@X=@BS>&'LJ#AIKV+X0(``.`#$`'@.#"/XM`@P^'P`,WA
MT`/-X:?-H.&&HJ#A`""2X`$PH^#0`,WA!2"2X``PH^($`(#A`$"2X`,``.JA
MZ]EN`````-R\&X\``````%"CX@"PC>4$P(WE\$/-X=!`S>%VSXWB"1^@X0I`
MA.'0H\WA*!&!X0@/H.$$H)K@`+"KX@I`H.$+4*#A*3&@X=B@3.$$@*#A^$/-
MX0%`@.$#4('AV`+-X00@H.$%,*#A`D"`X0-0@>'P(\WA!""@X04PH.'01LWA
M`)"@XP)`!.`#4`7@T"/-X?!`S>$`0*#AH!!/XM``P>$"0`3@T"#-X0A0G>4*
M`)#@"Q"AX`0@@N$%`)#@J4V@X01`C>4`$*'BB;*@X0)`D.``4*'BJ+V+X0"P
MC>7X0,WAT$#-X8BBH.$''Z#A"D"$X=B@S>$F$8'A!@^@X02@FN`G,:#AT&#,
MX0"PJ^(H4)WE\&;-X?"DS>$*8*#A`["!X0&@@.'0(\WA"@"@X0L0H.$`H(+A
M^`#-X=@#S>$#$*#A`'"@XPH``.``0*#A`@"@X=@@S>&'LJ#AIKV+X0(``.`#
M$`'@6S]/XM`@P^'P`,WAT`;-X:?-H.&&HJ#A`""2X`$PH^#0`,WA!2"2X``P
MH^($`(#A`$"2X`!0H^(`L(WE!,"-Y?A"S>'00,WA"1^@X2@1@>$*0(3AV*+-
MX0@/H.$I,:#A!*":X`"PJ^(*0*#A"U"@X02`H.'X0\WA`4"`X0-0@>'8`,WA
M>L^-X@0@H.$%,*#A`D"`X0-0@>'8H$SA^"+-X00@H.$%,*#AT$3-X0"0H.,"
M0`3@`U`%X-@BS>'P0,WA`$"@X2,>3^+0`,'A`D`$X-`@S>$P4)WE"@"0X`L0
MH>`$((+A!0"0X*E-H.$$0(WE`!"AXHFRH.$"0)#@`%"AXJB]B^$`L(WE\$/-
MX=!`S>&(HJ#A!Q^@X0I`A.'0H\WA)A&!X08/H.$$H)K@)S&@X=!@S.$`L*OB
M"%"=Y?!FS>'PI,WA"F"@X0.P@>$!H(#AV"+-X0H`H.$+$*#A`*""X?`#S>'8
M`\WA`Q"@X0!PH.,*``#@`$"@X0(`H.'0(\WAA[*@X::]B^$"``#@`Q`!X+\_
M3^+0(,/A\`#-X=`&S>&GS:#AAJ*@X0`@DN`!,*/@T`#-X04@DN``,*/B!`"`
MX0!`DN``4*/B`+"-Y03`C>7X0,WAT$#-X0D?H.$H$8'A"D"$X=B@S>$(#Z#A
M*3&@X02@FN``L*OB"D"@X0M0H.$$@*#A^$#-X0%`@.$#4('AT`/-X00@H.$%
M,*#A`D"`X0-0@>'X(\WA!""@X04PH.'01,WA?L^-X@"0H.,"0`3@`U`%X-B@
M3.'P0,WAV"/-X0!`H.$U'H_BT`#!X0)`!.#0(,WA*%"=Y0H`D.`+$*'@!"""
MX04`D."I3:#A!$"-Y0`0H>*)LJ#A`D"0X`!0H>*HO8OA`+"-Y?A"S>'00,WA
MB**@X0<?H.$*0(3AV*+-X281@>$&#Z#A!*":X"<QH.'08,SA`+"KXC!0G>7P
M9LWA\*3-X0I@H.$#L('A`:"`X=@CS>$*`*#A"Q"@X0"@@N'X`LWAV`#-X0,0
MH.$`<*#C"@``X`!`H.$"`*#AV"+-X8>RH.&FO8OA`@``X`,0`>"A/X_BT"##
MX?``S>'0!LWAI\V@X8:BH.$`()+@`3"CX-``S>$%()+@`#"CX@0`@.$`0)+@
M`%"CX@3`C>4`L(WE^$#-X=!`S>$)/Z#A*#&#X0I`A.'8H,WA*1&@X0@OH.$$
MH)K@`+"KX@M0H.$!L(/AV`+-X0J`H.$*0*#A`Z""X0H@H.$"H(#A\$;-X0LP
MH.$*0*#AT*3-X0(<C>("``#@!*`*X`I`H.'P),WAT*#!X0`@H.$='H_BT`#!
MX0"0H..H/:#A`*":X(G"H.$!L*O@B3*#X:@=C.$X4)WEB,*@X000C>4(,(WE
M`,"-Y:G-H.$,P(WE!`""X04@FN``,*OBV$#-X0"@DN#0`,WA`+"CX@<_H.$`
M0(3A!*":X`"PJ^(F,8/A!B^@X2<1H.'XH,WA"F"@X0&P@^$#H(+AT"3-X=`&
MS>$*0*#A"U"@X02@@N'P0\WA"@``X`!`H.$#$*#A`@"@X=`CS>$H4)WE`'"@
MXP(``.`#$`'@A[*@X?``S>&"'XWBIKV+X=`@P>'X$(_BT`#!X:?-H.&&HJ#A
M`""2X`$PH^#0`,WA!2"2X``PH^($`(#A`$"2X`!0H^(`L(WE!,"-Y?A"S>'0
M0,WA"3^@X2@Q@^$*0(3AV*+-X2D1H.$(+Z#A!*":X`"PJ^(+4*#A`;"#X=`#
MS>$*@*#A"D"@X0.@@N$*(*#A`J"`X?!&S>$+,*#A"D"@X=B@S>$A'HWB`@``
MX`2@"N#X(\WA"D"@X0`@H.'0H,'A3!"/XM``P>$`D*#C0%"=Y0"@FN")PJ#A
M`;"KX*@]H.&H'8SAB,*@X8DR@^$`P(WEJ<V@X00`@N$(,(WE!2":X`S`C>4$
M$(WEV$#-X00``.H``*#AW+P;CP````#<O!N/```````PJ^(`H)+@T`#-X0"P
MH^('/Z#A`$"$X02@FN``L*OB)C&#X08OH.$G$:#A"F"@X?B@S>$!L(/A`Z""
MX0I`H.$+4*#AV"/-X?A"S>'0!LWA!*""X0,0H.$*``#@`$"@X0(`H.'8(LWA
M,%"=Y0!PH.,"``#@`Q`!X(>RH.'P`,WAAA^-XJ:]B^'0(,'AG!!/XM``P>&G
MS:#AAJ*@X0`@DN`!,*/@T`#-X04@DN``,*/B!`"`X0!`DN``4*/B`+"-Y03`
MC>7P0\WAT$#-X0D_H.$H,8/A"D"$X="CS>$I$:#A""^@X02@FN``L*OB"U"@
MX0&P@^'8`LWA"H"@X0I`H.$#H(+A"B"@X0*@@.'P1LWA"S"@X0I`H.'8H,WA
M(AZ-X@(``.`$H`K@\"3-X0I`H.$`(*#AT*#!X5(?3^+0`,'A`)"@XSA0G>4`
MH)K@B<*@X0&PJ^"H/:#AJ!V,X8C"H.$`P(WEB3*#X:G-H.$$$(WE!`""X0@P
MC>4%()K@#,"-Y=A`S>$`,*OB`*"2X-``S>$`L*/B!S^@X0!`A.$$H)K@`+"K
MXB8Q@^$&+Z#A)Q&@X0I@H.'XH,WA`;"#X0.@@N'0),WAT`;-X0I`H.$+4*#A
M!*""X?!#S>$*``#@`$"@X0,0H.$"`*#AT"/-X0!PH..&HJ#A`@``X`,0`>"'
MLJ#A\`#-X8H?C>*FO8OAT"#!X2(>3^+0`,'AI\V@X0`@DN`!,*/@T`#-X0"P
MC>4H4)WE!`"`X04@DN``,*/B`$"2X`!0H^($P(WE^$+-X=!`S>$)/Z#A*#&#
MX0I`A.'8HLWA*1&@X0@OH.$$H)K@`+"KX@M0H.$!L(/AT`/-X0J`H.$*0*#A
M`Z""X0H@H.$"H(#A\$;-X0LPH.$*0*#AV*#-X2,>C>("``#@!*`*X/@CS>$*
M0*#A`""@X="@P>&S'T_BT`#!X0"0H.-`4)WE`*":X(G"H.$!L*O@J#V@X:@=
MC.&(PJ#A`,"-Y8DR@^&IS:#A!!"-Y00`@N$(,(WE!2":X`S`C>780,WA`#"K
MX@"@DN#0`,WA`+"CX@<_H.$`0(3A!*":X`"PJ^(F,8/A!B^@X2<1H.$*8*#A
M^*#-X0&P@^$#H(+AV"/-X=`&S>$*0*#A"U"@X02@@N'X0LWA"@``X`!`H.$#
M$*#A`@"@X=@BS>$P4)WE`'"@XP(``.`#$`'@A[*@X?``S>&.'XWBIKV+X=`@
MP>'1'X_BT`#!X:?-H.&&HJ#A`""2X`$PH^#0`,WA!2"2X``PH^($`(#A`$"2
MX`!0H^(`L(WE!,"-Y?!#S>'00,WA"3^@X2@Q@^$*0(3AT*/-X2D1H.$(+Z#A
M!*":X`"PJ^(*0*#A"U"@X0&P@^'P1,WAV`+-X0J`H.$#H(+A"B"@X0I`@.$+
M,*#AV*#-X0D=C>("``#@!*`*X/`CS>$*0*#A`""@X="@P>&G'X_BT`#!X0"0
MH.,X4)WE`*":X(G"H.$!L*O@J#V@X:@=C.&(PJ#A`,"-Y8DR@^&IS:#A!!"-
MY0@PC>4,P(WE!`""X04@FN``,*OBV$#-X0"@DN#0`,WA:,"=Y0"PH^(`0(3A
M!*":X`<_H.$F,8/A`+"KX@8OH.$G$:#AT&#,X?BCS>$`L*#C\&#-X0I@H.$+
M<*#A`Z""X0&P@^$*(*#A"S"@X=`#S>'X(,WAT"3-X0I`@.$+4('A!"`"X`4P
M`^#00,WA\"3-X=@@S>&'LJ#AIKV+X0(``.!Q/X_BT"##X0"PC>6&HJ#A!""2
MX`4PH^`)7Z#A\";-X=`DS>$H,)WE*%&%X0`@@N'0!LWA"$^@X06`A.$#`)#@
M`!"AXJ<]H.$"()#@!#"-Y0`PH>(I$:#A^"+-X=`@S>$!D(7A"`"@X0H@@N'8
MHLWA"1"@X=B`S>$"H)K@`+"KX@"`*.#PI,WA^`+-X24>C>(`L*#CT$#!X4T?
MC^+0`,'A"S"@X8NRH.$`0)3@`5"EX#`0G>7P1LWAV$/-X:J]B^$`L(WE"$`D
MX`2`H.'01LWA"B"@X8JBH.$!0)3@HQV@X000C>4`4*7B"`"4X``0I>+0@,WA
M\`/-X0=?H.$*@(CAT*/-X291A>$&3Z#A"*":X`"PJ^(*@*#A"Y"@X2<1H.'X
M@\WA`&"@XP"0H.,`<*#C","=Y?!@S>$!<(7AB1*@X000C>66'XWB!6"$X=``
MP>%\4(_BT$#%X0:@H.$'L*#A!`"0X`40H>#PH\WAV&+-X0&PH.$$$)WE"F`F
MX*@=@>$$$(WE`*"@X=`$S>$,0)K@B,*@X08`(.``P(WE`&"@X0!0J^(&H)3@
MT&#-X:@-H.&)`H#A`+"EX@-?H.$`8(;A(E&%X2,1H.$#``#JW+P;CP````#6
MP6+*``````:@FN`!,(7A``"@XP`0H./88$[A\`#-X:H=H.$`$(WE`D^@X=`#
MS>$%((3A\&;-X0"PJ^+01LWA`@`@X/@@S>%0,$_BT"##X?"DS>$`L*#C"W"@
MX00@DN"+LJ#A!3"CX*J]B^'80\WA`+"-Y2C`G>4`0"3@#""2X``PH^($0)+@
M`%"CXJ?-H.$$P(WE^$+-X=!`S>$*8*#ABJ*@X0I`A.'8HLWA"1^@X2@1@>$I
M,:#A!*":X`.0@>$`(*#C`#"@XP@/H.'P(,WA`8"`X:H]H.'8`,WA`#"-Y9H_
MC>+X@LWA"``@X-`@P^'XD$_BT(#)X0"PJ^(*0*#A"""2X`M0H.$),*/@T(3-
MX3#`G>7X0\WA`%"@XPP@DN``@"C@`#"CXH6RH.$(@)+@`)"CXJJ]B^&ES:#A
M`+"-Y03`C>7P@\WAT(#-X8JBH.$''Z#A"H"(X="CS>$F$8'A)S&@X0B@FN`#
M<('A`""@XP`PH.,&#Z#A\"#-X0%@@.&J/:#AV`+-X0`PC>4G/HWB!@`@X-`@
MP^'P8\WA:7]/XM!@Q^$`L*OB","=Y08@DN`',*/@V&/-X0"0H.,,()+@`&`F
MX/"DS>$`,*/BB;*@X09@DN``<*/BJKV+X:G-H.$`L(WE!,"-Y?A@S>'08,WA
M"H"@X8JBH.$*8(;AV*#-X04?H.$D$8'A!J":X`0/H.$E,:#A`4"`X0"PJ^(#
M4('A``"@XP`0H./XH\WA!""@X?``S>$%,*#AJAV@X0`0C>70`\WA^"#-X9X_
MC>($`"#@T"##X9=?3^+00,7A*,"=Y0"PH.,$()+@!3"CX-!$S>$+<*#A#""2
MX`!`).``,*/BB[*@X01`DN``4*/BJKV+X:?-H.$`L(WE!,"-Y?A"S>'00,WA
M"F"@X8JBH.$*0(3AV*+-X0D?H.$H$8'A*3&@X02@FN`#D('A`""@XP`PH.,(
M#Z#A\"#-X0&`@.&J/:#AV`#-X0`PC>4*/8WB^(+-X0@`(.#0(,/A`YQ/XM"`
MR>$`L*OB"D"@X0@@DN`+4*#A"3"CX-B#S>$PP)WE\$3-X0!0H.,,()+@`(`H
MX``PH^*%LJ#A"("2X`"0H^*JO8OAI<V@X0"PC>4$P(WE\(/-X="`S>&*HJ#A
M!Q^@X0J`B.'0H\WA)A&!X2<QH.$(H)K@`W"!X0`@H.,`,*#C!@^@X?`@S>$!
M8(#AJCV@X=@"S>$`,(WEHC^-X@8`(.#0(,/A\&/-X=-_C^+08,?A`)"@XP"P
MJ^(&()+@^*/-X8FRH.$',*/@JKV+X=!DS>$`L(WE","=Y0!@)N`,()+@`#"C
MX@9@DN``<*/BJ<V@X03`C>7X8,WAT&#-X0J`H.&*HJ#A"F"&X=B@S>$%'Z#A
M)!&!X00/H.$E,:#A!J":X`%`@.$#4('A``"@XP`0H.,$(*#A\`#-X04PH.&J
M':#A`!"-Y=`#S>'X(,WA*3Z-X@0`(.#0(,/AIU^/XM!`Q>$`L*OB*,"=Y00@
MDN`%,*/@V$/-X?"DS>$`L*#C"W"@X0P@DN``0"3@`#"CXHNRH.$$0)+@`%"C
MXJJ]B^&GS:#A`+"-Y03`C>7X0LWAT$#-X0I@H.&*HJ#A"D"$X=BBS>$)'Z#A
M*!&!X2DQH.$$H)K@`Y"!X0`@H.,`,*#C"`^@X?`@S>$!@(#AJCV@X=@`S>$`
M,(WEIC^-X@@`(.#0(,/A^(+-X1^>C^+0@,GA`+"KX@I`H.$(()+@"U"@X0DP
MH^#0A,WA,,"=Y?A#S>$`4*#C#""2X`"`*.``,*/BA;*@X0B`DN``D*/BJKV+
MX:7-H.$`L(WE!,"-Y?"#S>'0@,WABJ*@X0<?H.$*@(CAT*/-X281@>$G,:#A
M"*":X`-P@>$`L*OB`""@XP`PH.,&#Z#A`6"`X?"DS>'P(,WAV`+-X:H]H.$`
M,(WE*CZ-XO!CS>$&`"#@T"##X4]_C^+08,?A","=Y0"0H.,&()+@!S"CX-AC
MS>$,()+@`#"CX@!@)N`&8)+@B;*@X0!PH^*JO8OAJ<V@X0"PC>4$P(WE^&#-
MX=!@S>$*@*#ABJ*@X0I@AN'8H,WA!1^@X201@>$$#Z#A)3&@X0:@FN`!0(#A
M`U"!X0``H.,`$*#C!""@X?``S>$%,*#AJAV@X0`0C>70`\WA^"#-X:H_C>($
M`"#@T"##X910C^+00,7A`+"KXBC`G>4$()+@!3"CX-!$S>'XH\WA`+"@XPMP
MH.$,()+@`$`DX``PH^*+LJ#A!$"2X`!0H^*JO8OAI\V@X0"PC>4$P(WE^$+-
MX=!`S>$*8*#ABJ*@X0I`A.'8HLWA"1^@X2@1@>$I,:#A!*":X`.0@>$`(*#C
M`#"@XP@/H.'P(,WA`8"`X:H]H.$$``#J``"@X=;!8LH`````UL%BR@````#8
M`,WA`+"KX@`PC>4K/HWB"D"@X0M0H.$(`"#@T"##X?B"S>$TD$_BT(#)X?!$
MS>$`4*#C"""2X(6RH.$),*/@JKV+X=B#S>$`L(WE,,"=Y0"`*.`,()+@`#"C
MX@B`DN``D*/BI<V@X03`C>7P@\WAT(#-X8JBH.$''Z#A"H"(X="CS>$F$8'A
M)S&@X0B@FN`#<('A`""@XP`PH.,&#Z#A\"#-X0%@@.&J/:#AV`+-X0`PC>6N
M/XWB\&/-X08`(.#0(,/AU'!/XM!@Q^$`L*OB","=Y08@DN`',*/@T&3-X0"0
MH.,,()+@`&`FX/BCS>$`,*/BB;*@X09@DN``<*/BJKV+X:G-H.$`L(WE!,"-
MY?A@S>'08,WA"H"@X8JBH.$*8(;AV*#-X04?H.$D$8'A!`^@X24QH.$&H)K@
M`4"`X0-0@>$``*#C`!"@XP0@H.'P`,WA!3"@X:H=H.$`$(WET`/-X?@@S>$+
M/8WB!``@X-`@P^%A7T_BT$#%X0"PJ^(HP)WE!""2X`4PH^#80\WA\*3-X0"P
MH.,+<*#A#""2X`!`).``,*/BB[*@X01`DN``4*/BJKV+X:?-H.$`L(WE!,"-
MY?A"S>'00,WA"F"@X8JBH.$*0(3AV*+-X0D?H.$H$8'A!*":X`"PJ^(I,:#A
M"D"@X0.0@>$+4*#A`""@XP`PH.,(#Z#A`8"`X?A#S>'P(,WAV`#-X:H]H.$`
M,(WELC^-XOB"S>$(`"#@T"##X0F=3^+0@,GA,,"=Y0!0H.,(()+@"3"CX-"$
MS>$,()+@`#"CX@"`*.`(@)+@A;*@X0"0H^*JO8OAI<V@X0"PC>4$P(WE\(/-
MX="`S>&*HJ#A!Q^@X0J`B.'0H\WA)A&!X2<QH.$(H)K@`W"!X0`@H.,`,*#C
M!@^@X?`@S>$!8(#AJCV@X=@"S>$`,(WE+3Z-XO!CS>$&`"#@T"##X;=_3^+0
M8,?A`+"KX@C`G>4&()+@!S"CX-ACS>$`D*#C#""2X`!@)N#PI,WA`#"CXHFR
MH.$&8)+@`'"CXJJ]B^&IS:#A`+"-Y03`C>7X8,WAT&#-X0J`H.&*HJ#A"F"&
MX=B@S>$%'Z#A)!&!X00/H.$E,:#A!J":X`%`@.$#4('A``"@XP`0H.,$(*#A
M\`#-X04PH.&J':#A`!"-Y=`#S>'X(\WAMC^-X@"PJ^($`"#@T"##X99?C^+0
M0,7A^*#-X0"PH.,+<*#A!""2X(NRH.$%,*/@JKV+X=!$S>$`L(WE*,"=Y0!`
M).`,()+@`#"CX@1`DN``4*/BI\V@X03`C>7X0LWAT$#-X0I@H.&*HJ#A"D"$
MX=BBS>$)'Z#A*!&!X02@FN``L*OB"D"@X0M0H.$(#Z#A\$3-X0!0H.,%L*#A
M`$"@XP!0H.,I,:#A\$#-X0%`@.$#4('ABS*@X00PC>4$@*#A!9"@X2X^C>+X
M@LWAT"##X6:?C^+0@,GA!#"=Y=@#S>&J/8/A"""2X`0PC>4$`"#@`H"@X0-`
MH.'8(,WA,,"=Y0=?H.$`("+@`@"@X0P@F."*PJ#A`,"-Y0"`DN#0(,WA`#"@
MXR91A>$$((+A`H"8X`@@H.$&3Z#A\"#-X2<1H.$%@(3A`9"%X=!`S>$`8*#C
M`'"@XX42H.'X8,WA#!"-Y=@"S>&Z/XWB\(/-X=`@P^$(`"#@])"/XM"`R>$,
MP)WEI&V@X0*`F.`((*#AT(3-X:3-C.$,P(WE`(`HX`@`H.'0@,WA.,"=Y85B
MAN&(,J#A"#"-Y=B`S>$,0)+@`""4X`:`B.$(@)+@T"'-X0`PH.,+'Z#A"""2
MX$R`G>4J$8'A"@^@X?`@R.'81<WAT"#-X0&@@.'0`LWA,#"=Y00@DN#01<WA
M`P"0X"@PG>4"8*#A`T"4X`!0I>+8(<WA5#"?Y?!`S>'TXIWE!D"@X0#`D^70
M8,WA"B"2X`!0H.,`$*#C`'"@XP`PH.,,`%[A^$#(X?@!R.'P8LCA\"'(X0$`
M`!J_WXWB\(^]Z/3N_^L``*#AUL%BR@````"@O0(`\$<MZ0!P4.(L```*M#"?
MY0"0D^4``%GC)@``"@!0U^4``%7C/0!5$P%0H!,`4*`#$@``&@!`F>4``%3C
M#0``"@&`H.$)8*#A!2"@X0<0H.$$`*#A9.__ZP``4.,"```:!3#4YST`4^,+
M```*!$"VY0``5./S__\:!`"@X?"'O>@'4*#A`3#UY0``4^,]`%,3^___&@=0
M1>#E___J"6!&X`%0A>)&8:#A!4"$X`!@B.4$`*#A\(>]Z`E`H.'M___J!T"@
MX>O__^H0P`(`<$`MZ0!`H.%P8)_E<%"?Y0C03>(`,);E!#"-Y0T0H.$$`*#A
MPO__ZP``4.,,```*`!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($
M()/E``!2XP0@@^3[__\:[?__Z@0@G>4`,);E`P!2X0$``!H(T(WB<("]Z)WN
M_^N@O0(`$,`"`/!/+>D!0*#A`"#1Y?!1G^44T$WB/0!2XP%`@0(`,)7E`&"@
MX00`H.$,,(WER^[_ZP@0C>(`<*#A!@"@X9K__^L`@%#B/```"L3N_^L``%?A
M,P``F@B`G>6HD9_E"(&@X0``UN4``%#C/0!0$P$`H!,``*`#!0``"@8`H.$!
M,/#E``!3XST`4Q/[__\:!@!`X`)PA^(``(?@`'"9Y9WN_^L``%#C"`"'YU(`
M``H`()GE"!"=Y0`PUN4!8(;B`1&2YST`4^,``%,3`##!Y08```H!(('B`3#6
MY`(0H.$``%/C/0!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!,.+E
M^___&@``H.,,()WE`#"5Y0,`4N$X```:%-"-XO"/O>@!,$CB`2#4Y```4N,!
M(./E^___&O+__^K$D)_E`+"9Y0"@F^4``%KC)P``"@@PH.$+(*#A````Z@HP
MH.$$$++E`:"#X@``4>/Z__\:`S"#X@,1H.&,,)_E`""3Y0``4N,+```*"P"@
MX4#N_^L``%#C``")Y18```H`,*#A"H&@X0$@BN(`$*#C`A&#YPB@C>6I___J
M`2"@XP$`H.$`((/E4^[_ZP`P4.($,(WE"```"@J!H.$+$*#A"""@X0?N_^L$
M,)WE`#")Y>S__^H($*#CW___Z@``X./"___J&N[_ZZ"]`@`0P`(`*,`"`/!/
M+>E\T$WB+%&?Y0!P4.(`,)7E=#"-Y0(```H`,-?E``!3XP4``!IT()WE`#"5
MY0,`4N$_```:?-"-XO"/O>@J[O_K`&!0XO;__PKLL)_E`*#@XP&0H.,&`*#A
M?>[_ZP``4.,L```*$S#0Y2XP<^(%```:%##0Y0``4^/U__\*+C!SX@`P8Q(5
M,-`%``!3X_#__PH30(#B!P"@X2ON_^L`@*#A!`"@X2CN_^L``(C@`@"`XA/N
M_^L+,*#A"B"@X0D0H.$$0(WE`'"-Y0"`H.$M[O_K"""-X@@0H.$#`*#C9>[_
MZP$`<.,(`*#A`P``"A@PG>4/.@/B`0E3XPL```K<[?_K"`"@X;SM_^L&`*#A
M4.[_ZP``4./2__\:!@"@X63N_^L'`*#AP.W_Z[W__^JR___K\O__ZLCM_^N@
MO0(`+'<!`'!`+>D`4*#A;$"?Y0``E.5:[O_K!1"@X5(O@.(#`*#C4.[_ZP``
M4.,!```*``"@XW"`O>@``)3E4.[_ZU@QD.4/.@/B`0E3XP4```H``)3E2N[_
MZU@QD.4/.@/B"@I3X_'__QH%`*#A`A"@XQSN_^L0#V_AH`*@X7"`O>@8P`(`
M\$`MZ0':3>+,4)_E#-!-X@'*C>(`,)7E!,",X@!@H.$!<*#AM""?Y000C>*P
M`)_E`#",Y:KM_^L``%#C'@``V@@PC>(!0$#B!""#X`0P4N4``%/C%@``"@!`
MH.$$(*#A+Q"@XP0`C>+Z[?_K``!0XQ$```IL,)_E``"3Y1_N_^L$,*#A!""-
MX@80H.$#[O_K`3J-X@0P@^(`()/E`#"5Y0,`4N$+```:`=J-X@S0C>+P@+WH
M``!4X^?__QHD,)_E``"3Y0WN_^L'(*#A!A"@X8#M_^OM___J;^W_ZZ"]`@#_
M#P``-'<!`!C``@`<,)_E$$`MZ0``D^4`[O_K$#"?Y1`@G^40$)_E$$"]Z+;M
M_^H8P`(`L'8!`$P5`0!$=P$`$$`MZ0C03>(T0)_E``"4Y?+M_^OL___K``"4
MY>_M_^L@,)_E`""@XP0@C>4`,(WE%""?Y100G^6[[?_K"-"-XA"`O>@8P`(`
M-'H!`$AR`0!@=P$`<$`MZ0+:3>+$4)_E(-!-X@(JC>(`,)7E'"""X@`P@N5V
M[?_KK#"?Y10@C>((((WE!#"-Y:`@G^6@,)_E`1"@XP``C>4(`)WE@>W_ZP``
M4.,<``"Z`3J-XB`P@^((,$/B"`"=Y0,0H.$!*J#C##"-Y3[M_^L`0%#B$@``
MN@$`A.)2[?_K`&!0X@0```H,$)WE!""@X1'M_^L`,*#C!##&YP(ZC>(<,(/B
M`""3Y0`PE>4&`*#A`P!2X00``!H"VHWB(-"-XG"`O>@`8*#C\___ZA3M_^N@
MO0(`A'<!``$0``!X=P$`Q?__ZO!/+>D!VDWBX#&?Y1S03>(!*HWB`#"3Y10@
M@N(`0*#A`6"@X<@!G^40$(WB`#""Y1'^_^LO$*#C`%"@X00`H.%`[?_K``!0
MXPT```H$$*#AH`&?Y5W^_^L$`*#A`3J-XA0P@^(`()/E@#&?Y0`PD^4#`%+A
M7```&@':C>(<T(WB\(^]Z`0`H.$H[?_K:!&?Y0"0H.$&`*#A7>W_ZP"@4.+I
M__\*`##:Y5"!G^50L9_E``!3XTQAG^4\<9_E-0``"@``5>,$```*"A"@X04`
MH.&S[/_K``!0XR4```H*`*#A$NW_ZP$@0.(",(K@`B#:YR\`4N,%```:`!"@
MXP`0P^4!('/E`0!`XB\`4N/Z__\*`3")X@``@^`(`%#ARO__RN0PG^4!*J#C
M`1"@XPA`C>4`#(WH%`"-X@OM_^L``);E5^W_ZQ00C>)2+X#B`P"@XT'M_^L`
M`%#C!0``&@``EN5/[?_K6#&0Y0\Z`^(""5/C$@``"@<0H.$``*#C).W_ZP``
M4.,`H*#AK___"@`PVN4``%/CR?__&@``5>,$```*:!"?Y04`H.%][/_K``!0
MX^___PI4H)_E`0"@X]/__^H!$*#C%`"-X@[M_^L``%#CY___&A00C>(8`)_E
M^_W_ZQ0`C>+F[/_KF___ZI/L_^N@O0(`C'<!`)AW`0"H=P$`_P\``+1W`0`8
MP`(`K'<!`(AW`0``,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!,-+D``!3X_K_
M_QH>_R_A<$`MZ0!`4.(K```*`%#4Y0``5>,H```*M>S_ZP$`0.(`((3@`@!4
MX0L``"H`,-3G+P!3XRD``!H!,$+B`P``Z@`0T^4!,$/B+P!1XR,``!H#`%3A
M`R"@X?C__QH"`%3A$P``"@$@0N($``#J`##2Y0$00N(O`%/C`@``&@$@H.$"
M`%3A^/__.@0@0N`",(+B`0I3XP\``(H!((+B!!"@X0$ZH.-P`)_E4NS_ZV@`
MG^5P@+WH+P!5XQ0``!H"`*#C>>S_ZP``4.,"```*+C"@X[`PP.%P@+WH``"@
MXW"`O>@!,$+B`P``Z@`0T^4!,$/B+P!1X]K__PH#`%3A`R"@X?C__SH"`%3A
MU?__&NC__^H(`)_E<$"]Z(KL_^HLP`(`M'<!`#!`+>DTT$WB2.&?Y0C`C>)$
M09_E#P"^Z`!0E.4/`*SH#P"^Z"Q0C>4`X)[E#P"LZ"@!G^6PX,SA:OW_ZR`!
MG^5H_?_K'`&?Y6;]_^L8`9_E9/W_ZQ0!G^5B_?_K$`&?Y6#]_^L,`9_E7OW_
MZP@!G^5<_?_K!`&?Y5K]_^L``9_E6/W_Z_P`G^56_?_K^`"?Y53]_^OT`)_E
M4OW_ZP00C>+L`)_E'/W_ZP`04.(!```*R`"?Y6W]_^L$$(WBU`"?Y17]_^L`
M$%#B`0``"L@`G^5F_?_K!!"-XL``G^4._?_K`!!0X@H```J(`)_E7_W_ZZP0
MG^5T`)_E7/W_ZRP@G>4`,)3E`P!2X1$``!HTT(WB,("]Z`00C>*(`)_E_OS_
MZP`04.("```*3`"?Y4_]_^ON___J"B"@XVP0G^49`(WB<.S_ZP``4./H__\:
M(Q"-XO3__^KAZ__KO'8!`*"]`@"X=P$`Q'<!`,QW`0#8=P$`X'<!`/!W`0",
M=P$`_'<!``AX`0`4>`$`F'<!`"!X`0`L>`$`.'@!`$QX`0!@>`$`;'@!`)QX
M`0!\>`$`D'@!`#!`+>D,T$WB8%"?Y6!`G^4``)7E`#"4Y0$`<.,$,(WE!0``
M"@0@G>4`,)3E`P!2X0T``!H,T(WB,("]Z`T0H.$P`)_ER/S_ZP``4.,$```*
M``#0Y3``4.,``%`3`0"@$P``H`,``(7E[?__ZJ_K_^L(P`(`H+T"`/QW`0`0
M0"WIC.O_ZX7K_^L``%#C``"0%1"`O>CP3RWI`&"@X0#AG^5$T$WB(,"-X@\`
MONCT<)_E#P"LZ`<`GN@@0)WE`#"7Y0``5.,'`(SH/#"-Y1D```K4L)_EU*"?
MY210C>(`D.#C!@``Z@80H.%FZ__K``!0XQ8```H$0)7D``!4XPT```H<$(WB
M!`"@X9?\_^L`@%#B`@``"@`@V.4``%+C\/__&@0`H.$&$*#AY/S_ZP1`E>0`
M`%3C\?__&CP@G>4`,)?E`P!2X14``!I$T(WB\(^]Z`8`H.&QZ__K%`"-Y0@`
MH.&NZ__K%#"=Y0``@^`"`(#BF.O_ZPB`C>5`"(WH"C"@X0D@H.$!$*#C%`"-
MY;+K_^L4$)WE!`"@X<C\_^O4___J8NO_Z^!V`0"@O0(`J'<!`*QW`0`D.9_E
M\$\MZ0!@H.&!W$WB!P"3Z#303>(XP(WB#$"#X@<`C.@DP(/B#P"TZ%#@C>)$
M4(WB#P"NZ`,`E.CL.)_E`P".Z`<`G.B!S(WB`#"3Y2S`C.('`(7H-!"-XM`(
MG^4`,(SE4_S_ZP!`4.("```*`##4Y0``4^,1`0`:D?__ZP!04.)$0(T"4```
M"@4`H.%UZ__K@`"@X0$`@.)@Z__K`##5Y0``4^,`D*#A#0``"H"HG^4)0*#A
M`(#@XP%PH.,`,(WE!`"@X0HPH.$((*#A!Q"@X7/K_^L!,/7E`D"$X@``4^/U
M__\:4`"=Y0``4.,2```*5$"-X@(``.H$`)3D``!0XPT```HT$(WB*?S_ZP!0
M4.+X__\*`##5Y0``4^/U__\*3?W_ZP``4./R__\*!0"@X6'K_^L`4%#B+P``
M&@!`H.,X<(WB$SZ-X@0Q@^#X4!/E``!5XR<```H`,-7E``!3XR0```H%`*#A
M._W_ZP%`A.($@8?@``!0XPH``!H$4)CD``!5XQL```H`,-7E``!3XQ@```H%
M`*#A+_W_ZP%`A.(``%#C]/__"@4`H.%"Z__K``!0X^+__PH`4*#A#@``ZCWK
M_^L``%#CQP``&@0`E.0``%#CO@``"C00C>+T^__K`#!0XOC__PH`,-/E``!3
MX_7__PKQ___J`%"@XP4`H.$8Z__K`$"@X0D`H.$5Z__K`$"$X`%+A.($0(3B
M!`"@X?[J_^L,-Y_E`"#@XP@PC>4\-Y_E`1"@XP0PC>4,D(WE]#:?Y0!0C>4`
M@*#A%.O_ZP@`H.$'':#C'>O_ZP$`<.,;```*U':?Y0``E^5:Z__K"!"@X5(O
M@.(#`*#C4.O_ZP!04.(@```*M":?Y0`PEN4!$*#C`("-Y0``DN6D)I_E'>O_
MZP!`H..!/(WB+#"#X@`@D^5P-I_E!`"@X0`PD^4#`%+AV@$`&H'<C>(TT(WB
M\(^]Z._J_^L`()#E$0!2X]___PI8%I_E`#"6Y00@C>54)I_E``"1Y0"`C>4!
M$*#C!>O_ZP!`H./F___J``"7Y3'K_^M8,9#E#SH#X@$)4^/8__\:``"7Y2OK
M_^M@D9#E<NK_ZP``6>'2__\:``"7Y27K_^M8,9#E@SN@X:,[H.$'#5/CR___
M&@0`H.&OZO_K-!"-X@!`H.'@!9_ED/O_ZP``4.->```*`'"6Y<[J_^L`$*#A
M!P"@X6K]_^L`<%#B5P``"@<`H.&RZO_K`P!0XP"0H.$+``#:!`!`X@``A^"<
M%9_E2.K_ZP``4.,%```:!`!9XSX!``H)D(?@!3!9Y2\`4^,Z`0`*FO[_ZP`0
M4.($```:!P"@X8GJ_^L`,%#B*#"-Y4```!I8%9_E6`6?Y<#[_^N1ZO_K8'6?
MY6`UG^4`(.#C!#"-Y0$0H.,`@(WE#'"-Y30UG^4';:#C,+6?Y0*@H.$!D*#A
M"`"-Y00`H.&7ZO_K$```ZI+J_^L`,)#E$0!3XQ$``!I\ZO_K$#6?Y0%0A>($
M,(WE#%"-Y1!PC>4`@(WE"S"@X0H@H.$)$*#A"`"-Y00`H.&%ZO_K!A"@X00`
MH.&.ZO_K`0!PX^G__PH(`*#A&^K_ZP00H.%\!)_EE/O_ZP0`H.&'_O_K>?__
MZH7^_^L$`*#A>^K_ZP!`H.%T___J#0"@XU#J_^N$5)_E4S"@XP"0H.'O_O_J
M`%"@X>3^_^H`<);EI?__Z@)0H.,`,.#C$2#@XP!0C>4WZO_K2Q^-X@8@H.,H
M`)WE].G_ZRPQW>4``%/C`@``&BTQW>5#`%/C&P$`"@!0H.,`4(WE`""@XP`P
MH.,H`)WE)^K_Z^H_C^+0(,/AZA^/XM``P>'J?X_BT&#'X?`GS>'I/X_BT"##
MX>F_C^+0H,OA^`;-X>!0C>4``*#C`!"@XP10H.'X*,WAH#"-XOAGS>'PJ,WA
M\`G-X?@)S>$L,(WE`BF@XTL?C>(H`)WES>G_ZP!`4.)5``#:Q'^@X=`)S>&'
M,:#AI#Z#X1PPC>6$,:#A&#"-Y=@AS>$`,*#C!&"@X0`@DN`#`%'A`@!0`=@)
MS>$!``":`0"0X@`0H>*FSJ#AA\&,X2#`C>6GSJ#A),"-Y=!BS>'@P)WE\"G-
MX0!@EN`!<*?@!@"@X0<0H.$``%SC^`G-X3,```I`<&SB!P!4X2PPG>4$<*"Q
M#`"#X`<@H.%+'XWBLNG_Z^`PG>4#,(?@0`!3X^`PC>7,__\:2S^-XF@`C>('
M0$3@!W"#X"KK_^L_`%3C&```VD!`1.(_H,3C@)"*X@F0A^!`L(?B0&!+XJ#@
MC>(``);E!!"6Y0@@EN4,,);E#L"@X1!@AN(+`%;A#P"LZ`S@H.'U__\::`"-
MXD"PAN(4Z__K"0!;X>[__QI`H(KB"G"'X#]`!.('$*#A2#"@XP0@H.$L`)WE
MK^G_Z^!`C>6E___J2W^-XMO__^HH`)WE).K_ZP5`H.&04)WEH'"-XG\@X..E
M,:#A/S`#X@$0@^(X`%'CF&"=Y0,@Q^>*``#*`0"'X#@@8>(`$*#CW^G_ZR;H
MH.$FQ*#A)1R@X24HH.$E-*#A)GR@X6@`C>+;8,WEWU#-Y=APS>79X,WEVL#-
MY=P0S>7=(,WEWC#-Y>7J_^MHX)WE<,"=Y7@`G>4N6*#A+CR@X>_@S>4NY*#A
M[N#-Y2SLH.&`$)WE\\#-Y?#@S>4LZ*#A+,2@X?+`S>4@S*#AB""=Y?<`S>7T
MP,WE(,B@X2`$H.'V`,WE(0R@X?L0S>7X`,WE(0B@X2$4H.'Z$,WE(AR@X?'@
MS>7_(,WE$^Z-XOP0S>4B&*#A(B2@X>U0S>7\L)_E[##-Y0%<C>+M8(WB]<#-
MY0B@3N+Y`,WE`)#@X_T0S>4!<*#C_B#-Y0```.H!,-;D`#"-Y04`H.$+,*#A
M"2"@X0<0H.$"4(7BB.G_ZP4`6N'U__\:`2R-XMPPG^4(((WEV""?Y0``H.,$
M((WE##"-Y2@!S>4`@(WEQ#"?Y0`@X.,!$*#C!`"@X7CI_^OV_O_J!&"6Y0``
M5N/!_O\*!@"@X6/I_^L#`%#CO?[_F@0`0.(``(;@?!"?Y?KH_^L``%#C!G"@
M`;;^_^H``*#AB:O-[P`````!(T5G`````/[<NI@`````\.'2PP````!V5#(0
M`````/QV`0"@O0(`C'<!`*AX`0"\>`$`L'@!`!C``@`@P`(`1'D!`,1X`0"(
M>@$``'D!`)QX`0#\=P$`('D!`#!Y`0"@>`$`"'D!`#1Z`0"T=P$`$'D!`$`@
M8>(!`(?@`!"@XU3I_^MH`(WB:.K_ZP<`H.$X(*#C`!"@XT[I_^MM___J+C'=
MY4$`4^/@_O\:+S'=Y4,`4^/=_O\:,#'=Y4@`4^/:_O\:,3'=Y44`4^/7_O\:
M`%"-Y2A0G>4`,.#C.2#@XP4`H.'_Z/_K2Q^-X@4`H.$I(*#CO.C_ZTLOC>*<
M,!_E"""-Y:`@'^4,,(WE!""-Y0"`C>6L,!_E`"#@XP$0H.,$`*#A'.G_ZYK^
M_^K/Z/_K%#.?Y?!/+>D4T$WB#&.?Y0`PD^4``);E##"-Y6#I_^L`0*#A``"6
MY5WI_^L($(WB:##0Y>@"G^5I,,3ESOG_ZP``4.,"```*`##0Y3$`4^.1```*
M@?S_ZP``EN50Z?_K"S"@XP$@H..X$I_EX^C_Z[1RG^4``%#C,```"A`@D.7T
M/Q?E`0!3XQB@DN4K``#:`%"@XY2RG^4%D*#A`4"@XPD``.H0$)+E"`"@X7SH
M_^OT/Q?E``!0XQT``!H!0(3B!`!3X0%0A>(9``#:``"6Y3/I_^L*$*#A"3"@
MX04@H.$.Z?_K`!!0XA````H`()'E\`\7Y0@PDN4$@9#G"S`#X`$+4^/F__\*
M``"6Y000C>4CZ?_K!!"=Y0(PH.,)(*#A`!"1Y9WH_^L`$*#AW?__ZO0_%^4!
M($/B!0!2X4H```H``);E%NG_ZP,PH.,!(*#CW!&?Y:GH_^L`0%#B"@``"@``
MEN4.Z?_K$#"4Y<0AG^4`$)/E@.C_ZQ`PE.4`,)/E"#"3Y0$%$^-6```:``"6
MY0/I_^L#,*#C`2"@XY@1G^66Z/_K`$!0X@H```H($(WBB`&?Y7#Y_^L`4%#B
M``"6Y4$```KVZ/_K$#"4Y04@H.$`$)/E:.C_ZP``EN7PZ/_K`$"@X0``EN7M
MZ/_K`2"@XTP1G^66Z/_K2"&?Y0`0H.$$`*#A7.C_ZP``EN7DZ/_K`#"@XP@0
MC>)I,,#E*`&?Y57Y_^L``%#C`$"@X>P/!^4=```*!QV@XP0`H.&6Z/_K`3"`
MXA$`4.,!`%,3+```BL0PG^4,()WE`#"3Y0,`4N$F```:%-"-XO"/O>@!`%/C
MLO__V@%`H.,``);ER.C_ZPH0H.$8Z/_K]#\7Y0%`A.($`%/A]___RJC__^H!
M,-#E``!3XVO__PII___J\`\7Y</\_^L``%#C`$"@X>P/!^7;__\:A`"?Y6KH
M_^NTZ/_K$""4Y?`_%^4``)+E`!"3Y6_Z_^N[___J``"6Y:SH_^L0,)3E`!"3
MY7/H_^NB___J#NC_Z_`?%^4`,*#A!""@X0`0D>4X`)_E5NC_ZZ"]`@`8P`(`
MX'<!`)AY`0`@X`(```0@`*!Y`0"D>0$`K'D!`)AW`0"P>0$`R'D!`(QW`0#0
M>0$`]'D!`'!`+>D`4*#A=?O_ZP`PT.4``%/C%0``"@$@@.(`0*#A+P!3XP)`
MH`$!,-+D``!3X_K__QH?_/_K``!5XP``4!-P@+T(`##5Y0``4^-P@+T((!"?
MY00`H.&XY__K``!4X7"`O1@%`*#A<$"]Z,7Y_^H`0*#A[O__ZKQX`0`4P)_E
M%#"?Y0S`C^`#,)SG``!3XP`PDQ76Y__JM$@!`!@!``#P1RWI`'"@X4A@G^5(
M4)_E!F"/X`50C^`%8$;@`8"@X0*0H.&5Y__K1F&PX?"'O0@`0*#C`4"$X@0P
ME>0)(*#A"!"@X0<`H.$S_R_A!`!6X??__QKPA[WH0$<!`#A'`0`>_R_A"$`M
MZ0B`O>@!``(`<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("``````:'H!`'AZ`0"`>@$`B'H!`)!Z`0"D>@$``````&!Z`0"(
M=P$``````&!X`0!D>`$`5'H!`)!W`0!<>@$``````$!Z`0!(>@$``````"5S
M+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`
M+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O
M````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"
M54<```!005)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?
M1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)
M4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,
M14%./0``,0```%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@`````8````
M<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP,S8```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!414U0
M1$E2`%1-4``O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!
M4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42````%-(3$E"7U!!5$@``&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X
M(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T
M(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E
M:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A
M9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED
M>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@
M/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q
M,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD
M;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K
M*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M
M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE
M(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ
M,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F
M:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L
M<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM
M>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M
M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@
M>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L
M("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE
M.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S
M92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D
M)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%2
M7TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E
M;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M.PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?
M0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V
M86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E
M='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`
M7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC
M('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS
M:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?
M87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL
M97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!B_W\!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````P;`0#D&@$`````````````````````
M``````````````````$````!`````0```-\!```!````Z@$```$```#T`0``
M`0```$,"```!````CP,```$```"U`P``#````,`4`0`-````I'8!`!D```"4
MO0(`&P````0````:````F+T"`!P````$````]?[_;[0!`0`%````)`P!``8`
M``!D!0$`"@```!D%```+````$````!4``````````P```."^`@`"````$`(`
M`!0````1````%P```+`2`0`1````>!(!`!(````X````$P````@````8````
M`````/O__V\!````_O__;Q@2`0#___]O`P```/#__V\^$0$`````````````
M````````````````````````````````````````````````````N+T"````
M````````S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!
M`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`
MS!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,
M%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4
M`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!
M`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`S!0!`,P4`0#,%`$`
M``````3``@````````````````#_____L'H!`$=#0SH@*%)A<W!B:6%N(#8N
M-"XP+3$K<G!I,2D@-BXT+C`@,C`Q-S`W,#0`1T-#.B`H4F%S<&)I86X@-BXS
M+C`M,3@K<G!I,2D@-BXS+C`@,C`Q-S`U,38`02X```!A96%B:0`!)`````4V
M``8&"`$)`0H"$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M:F-R`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O
M;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````````
M````````````````````````"P````$````"````5`$!`%0!```9````````
M```````!`````````!,````'`````@```'`!`0!P`0``(```````````````
M!``````````A````!P````(```"0`0$`D`$``"0```````````````0`````
M````-````/;__V\"````M`$!`+0!``"P`P``!0`````````$````!````#X`
M```+`````@```&0%`0!D!0``P`8```8````!````!````!````!&`````P``
M``(````D#`$`)`P``!D%``````````````$`````````3@```/___V\"````
M/A$!`#X1``#8````!0`````````"`````@```%L```#^__]O`@```!@2`0`8
M$@``8`````8````#````!`````````!J````"0````(```!X$@$`>!(``#@`
M```%``````````0````(````<P````D```!"````L!(!`+`2```0`@``!0``
M`!<````$````"````'P````!````!@```,`4`0#`%```#```````````````
M!`````````!W`````0````8```#,%`$`S!0``"P#``````````````0````$
M````@@````$````&````^!<!`/@7``"L7@`````````````(`````````(@`
M```!````!@```*1V`0"D=@``"```````````````!`````````".`````0``
M``(```"L=@$`K'8```!!``````````````0`````````E@````$``'""````
MK+<!`*RW```(````#0`````````$`````````*$````!`````@```+2W`0"T
MMP``!```````````````!`````````"K````#@````,```"4O0(`E+T```0`
M``````````````0````$````MP````\````#````F+T"`)B]```$````````
M```````$````!````,,````!`````P```)R]`@"<O0``!```````````````
M!`````````#(`````0````,```"@O0(`H+T``!<```````````````@`````
M````U0````8````#````N+T"`+B]```H`0``!@`````````$````"````-X`
M```!`````P```."^`@#@O@``'`$`````````````!`````0```#C`````0``
M``,`````P`(``,```!````````````````0`````````Z0````@````#````
M$,`"`!#````L$``````````````(`````````.X````!````,``````````0
MP```60```````````````0````$```#W`````P``<```````````:<```"\`
M``````````````$``````````0````,``````````````)C````'`0``````
-```````!````````````
